@@ -12,6 +12,8 @@ Just for internal usage!
 
 =head2 log()
 
+=head2 reload()
+
 =head2 flush()
 
 =head2 errstr()
@@ -27,7 +29,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2008 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -41,8 +43,8 @@ use warnings;
 use Carp;
 use UNIVERSAL;
 
-our $VERSION = '0.07';
-our $ERRSTR  = '';
+our $VERSION = "0.09";
+our $ERRSTR  = "";
 
 sub new {
     my ($class, $options, $output) = @_;
@@ -65,17 +67,13 @@ sub log {
 
     my $output  = $self->{output};
     my $message = { };
-    my $wanted  = { message => join(' ', grep defined, @_) };
+    my $wanted  = { message => join(" ", grep defined, @_) };
 
     # The patterns must be generated for each output. The reason
     # is that each output can have their own time/date format
     # and the code which is executed can return another value.
     foreach my $r (@{$self->{wanted_pattern}}) {
-        if (ref($r->{code})) {
-            $wanted->{$r->{name}} = &{$r->{code}}($self, $level);
-        } else {
-            $wanted->{$r->{name}} = $r->{code};
-        }
+        $wanted->{$r->{name}} = &{$r->{code}}($self, $level);
     }
 
     if ($self->{message_pattern}) {
@@ -114,6 +112,16 @@ sub log {
         $message->{message} .= "\n";
     }
 
+    # The substr solution to determine if a newline exists
+    # at the end of the message is ~60% faster than the regex.
+    # Maybe it will be released in the future.
+    #if ($self->{newline}) {
+    #    my $last = substr $message->{message}, -1, 1;
+    #    if ($last eq "\015" || $last eq "\012" || $last eq "\015\012" || $last eq "\012\015") {
+    #        $message->{message} .= "\n";
+    #    }
+    #}
+
     $output->log($message)
         or return $self->_raise_error($output->errstr);
 
@@ -124,7 +132,7 @@ sub flush {
     my $self   = shift;
     my $output = $self->{output};
 
-    if ( UNIVERSAL::can($output, 'flush') ) {
+    if ( UNIVERSAL::can($output, "flush") ) {
         $output->flush
             or return $self->_raise_error($output->errstr);
     }
@@ -132,7 +140,17 @@ sub flush {
     return 1;
 }
 
-sub errstr { $ERRSTR }
+sub reload {
+    my ($self, $opts) = @_;
+
+    foreach my $key (keys %$opts) {
+        $self->{$key} = $opts->{$key};
+    }
+}
+
+sub errstr {
+    return $ERRSTR;
+}
 
 #
 # private stuff
@@ -154,14 +172,14 @@ sub _add_trace {
     }
 
     foreach my $i (reverse $skip..$#caller) {
-        $message->{message} .= ' ' x 3 . "CALL($i):";
+        $message->{message} .= " " x 3 . "CALL($i):";
         my $frame = $caller[$i];
         foreach my $key (qw/package filename line subroutine hasargs wantarray evaltext is_require/) {
             next unless defined $frame->{$key};
             if ($self->{debug_mode} == 1) { # line mode
                 $message->{message} .= " $key($frame->{$key})";
             } elsif ($self->{debug_mode} == 2) { # block mode
-                $message->{message} .= "\n" . ' ' x 6 . sprintf('%-12s', $key) . $frame->{$key};
+                $message->{message} .= "\n" . " " x 6 . sprintf("%-12s", $key) . $frame->{$key};
             }
         }
         $message->{message} .= "\n";
