@@ -50,6 +50,14 @@ Example:
 
     $screen->log("this message goes to the screen");
 
+=head2 validate()
+
+Validate a configuration.
+
+=head2 reload()
+
+Reload with a new configuration.
+
 =head2 errstr()
 
 This function returns the last error message.
@@ -75,7 +83,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2008 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -87,9 +95,9 @@ package Log::Handler::Output::Screen;
 use strict;
 use warnings;
 use Data::Dumper;
-use Params::Validate;
+use Params::Validate qw();
 
-our $VERSION = "0.04";
+our $VERSION = "0.06";
 our $ERRSTR  = "";
 
 sub new {
@@ -108,19 +116,57 @@ sub log {
     }
 
     if ($self->{log_to} eq "STDOUT") {
+        if ($self->{utf8}) {
+            binmode STDOUT, ":utf8";
+        }
         print STDOUT $message->{message}
             or return $self->_raise_error($!);
     } elsif ($self->{log_to} eq "STDERR") {
+        if ($self->{utf8}) {
+            binmode STDERR, ":utf8";
+        }
         print STDERR $message->{message}
             or return $self->_raise_error($!);
     } elsif ($self->{log_to} eq "WARN") {
+        # hmmm, should I really set utf8 for warnings?
         warn $message->{message};
     }
 
     return 1;
 }
 
-sub errstr { $ERRSTR }
+sub validate {
+    my $self = shift;
+    my $opts = ();
+
+    eval { $opts = $self->_validate(@_) };
+
+    if ($@) {
+        $ERRSTR = $@;
+        return undef;
+    }
+
+    return $opts;
+}
+
+sub reload {
+    my $self = shift;
+    my $opts = $self->validate(@_);
+
+    if (!$opts) {
+        return undef;
+    }
+
+    foreach my $key (keys %$opts) {
+        $self->{$key} = $opts->{$key};
+    }
+
+    return 1;
+}
+
+sub errstr {
+    return $ERRSTR;
+}
 
 #
 # private stuff
@@ -135,6 +181,11 @@ sub _validate {
             regex => qr/^(?:STDOUT|STDERR|WARN)\z/,
             default => "STDOUT",
         },
+        utf8 => {
+            type => Params::Validate::SCALAR,
+            regex => qr/^[01]\z/,
+            default => 0,
+        },
         dump => {
             type => Params::Validate::SCALAR,
             regex => qr/^[01]\z/,
