@@ -7,9 +7,9 @@ Log::Handler::Output::Socket - Send messages to a socket.
     use Log::Handler::Output::Socket;
 
     my $sock = Log::Handler::Output::Socket->new(
-        peeraddr    => '127.0.0.1',
+        peeraddr    => "127.0.0.1",
         peerport    => 44444,
-        proto       => 'tcp',
+        proto       => "tcp",
         timeout     => 10
     );
 
@@ -80,7 +80,7 @@ C<IO::Socket::INET> and don't want use C<peeraddr> and C<peerhost>.
 Example:
 
         connect => {
-            PerrAddr  => '127.0.0.1',
+            PerrAddr  => "127.0.0.1",
             PeerPort  => 44444,
             LocalPort => 44445
         }
@@ -95,7 +95,7 @@ Call C<log()> if you want to send a message over the socket.
 
 Example:
 
-    $sock->log('message');
+    $sock->log("message");
 
 =head2 connect()
 
@@ -105,6 +105,14 @@ Connect to the socket.
 
 Disconnect from socket.
 
+=head2 validate()
+
+Validate a configuration.
+
+=head2 reload()
+
+Reload with a new configuration.
+
 =head2 errstr()
 
 This function returns the last error message.
@@ -132,7 +140,7 @@ Jonny Schulz <jschulz.cpan(at)bloonix.de>.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2007-2008 by Jonny Schulz. All rights reserved.
+Copyright (C) 2007-2009 by Jonny Schulz. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
@@ -144,21 +152,23 @@ package Log::Handler::Output::Socket;
 use strict;
 use warnings;
 use Carp;
-use Params::Validate;
-use IO::Socket::INET;
 use Data::Dumper;
+use IO::Socket::INET;
+use Params::Validate qw();
 
-our $VERSION = '0.05';
-our $ERRSTR  = '';
+our $VERSION = "0.08";
+our $ERRSTR  = "";
 
 sub new {
-    my $class   = shift;
-    my $options = $class->_validate(@_);
-    my $self    = bless $options, $class;
+    my $class = shift;
+    my $opts  = $class->_validate(@_);
+    my $self  = bless $opts, $class;
+
     if ($self->{persistent}) {
         $self->connect
             or croak $self->errstr;
     }
+
     return $self;
 }
 
@@ -207,7 +217,7 @@ sub connect {
     if (@_) {
         $opts = @_ > 1 ? {@_} : shift;
     } else {
-        $opts = $self->{sock_opts};
+        $opts = $self->{sockopts};
     }
 
     $self->{socket} = IO::Socket::INET->new(%$opts)
@@ -218,8 +228,43 @@ sub connect {
 
 sub disconnect {
     my $self = shift;
-    $self->{socket}->close;
-    $self->{socket} = undef;
+
+    if ($self->{socket}) {
+        $self->{socket}->close;
+    }
+
+    delete $self->{socket};
+}
+
+sub validate {
+    my $self = shift;
+    my $opts = ();
+
+    eval { $opts = $self->_validate(@_) };
+
+    if ($@) {
+        return $self->_raise_error($@);
+    }
+
+    return $opts;
+}
+
+sub reload {
+    my $self = shift;
+    my $opts = $self->validate(@_);
+
+    $self->disconnect;
+
+    foreach my $key (keys %$opts) {
+        $self->{$key} = $opts->{$key};
+    }
+
+    if ($self->{persistent}) {
+        $self->connect
+            or croak $self->errstr;
+    }
+
+    return 1;
 }
 
 sub errstr {
@@ -228,6 +273,7 @@ sub errstr {
 
 sub DESTROY {
     my $self = shift;
+
     if ($self->{socket}) {
         $self->{socket}->close;
     }
@@ -255,7 +301,7 @@ sub _validate {
         },
         proto => {
             type => Params::Validate::SCALAR,
-            default => 'tcp',
+            default => "tcp",
         },
         timeout => {
             type => Params::Validate::SCALAR,
@@ -283,10 +329,10 @@ sub _validate {
     });
 
     if ($options{peeraddr} && $options{peerport}) {
-        $options{sock_opts}{PeerAddr} = delete $options{peeraddr};
-        $options{sock_opts}{PeerPort} = delete $options{peerport};
-        $options{sock_opts}{Proto}    = delete $options{proto};
-        $options{sock_opts}{Timeout}  = delete $options{timeout};
+        $options{sockopts}{PeerAddr} = delete $options{peeraddr};
+        $options{sockopts}{PeerPort} = delete $options{peerport};
+        $options{sockopts}{Proto}    = delete $options{proto};
+        $options{sockopts}{Timeout}  = delete $options{timeout};
     } elsif (!$options{connect}) {
         Carp::croak "missing mandatory parameter connect or peeraddr/peerport";
     }
